@@ -1,9 +1,10 @@
 package Dist::Zilla::PluginBundle::Author::SKIRMESS;
 
+use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
@@ -12,6 +13,17 @@ with qw(
   Dist::Zilla::Role::PluginBundle::Easy
 );
 
+sub mvp_multivalue_args { return qw/stopwords/ }
+
+has stopwords => (
+    is      => 'ro',
+    isa     => 'Maybe[ArrayRef]',
+    lazy    => 1,
+    default => sub {
+        exists $_[0]->payload->{stopwords} ? $_[0]->payload->{stopwords} : undef;
+    },
+);
+
 sub configure {
     my $self = shift;
 
@@ -26,6 +38,20 @@ sub configure {
             }
         ],
 
+        'Author::SKIRMESS::Test::XT::Test::CPAN::Meta',
+        'Author::SKIRMESS::Test::XT::Test::CPAN::Meta::JSON',
+        'Author::SKIRMESS::Test::XT::Test::DistManifest',
+        'Author::SKIRMESS::Test::XT::Test::Kwalitee',
+        'Author::SKIRMESS::Test::XT::Test::MinimumVersion',
+        'Author::SKIRMESS::Test::XT::Test::Mojibake',
+        'Author::SKIRMESS::Test::XT::Test::NoTabs',
+        'Author::SKIRMESS::Test::XT::Test::Perl::Critic',
+        'Author::SKIRMESS::Test::XT::Test::Pod',
+        'Author::SKIRMESS::Test::XT::Test::Pod::No404s',
+        'Author::SKIRMESS::Test::XT::Test::Portability::Files',
+        [ 'Author::SKIRMESS::Test::XT::Test::Spelling', { stopwords => $self->stopwords } ],
+        'Author::SKIRMESS::Test::XT::Test::Version',
+
         # Check at build/release time if modules are out of date
         [
             'PromptIfStale', 'stale modules, release',
